<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Bridge\Doctrine\Hydrator;

use Doctrine\ORM\Internal\Hydration\ObjectHydrator;

class PriceVariantHydrator extends ObjectHydrator
{
    protected function hydrateAllData(): array
    {
        $result = [];

        while ($row = $this->statement()->fetchAssociative()) {
            $this->hydrateRowData($row, $result);
        }

        return $result;
    }
}
