<?php

namespace CpCreation\VitiCore\Bridge\Symfony\Bundle\Twig\Components\Shop;

use Symfony\UX\TwigComponent\Attribute\AsTwigComponent;

#[AsTwigComponent('shop:LegalNotice', template: '@components/shop/LegalNotice.html.twig')]
final class LegalNotice
{
}
