{% extends 'base.html.twig' %}

{% block title %}{{ 'cgv.title'|trans({}, 'meta') }}{% endblock %}

{% block meta %}
    {{ include('partials/seo.html.twig', {
        title_key: 'cgv.title',
        description_key: 'cgv.description',
        robots: 'noindex,nofollow'
    }) }}
{% endblock meta %}
{% block main %}
    <section class="pt-4 bg-light">
        <div class="mx-4 lg:mx-8 large:mx-auto max-w-large pb-20 pt-16 sm:pb-28 sm:pt-20">
            <div class="mx-auto mb-10 max-w-4xl px-6 text-center sm:px-8">
                <h1 class="flex flex-col items-center font-serif text-3xl uppercase tracking-[0.14em] text-dark sm:text-4xl lg:text-5xl after:mt-5 after:h-[2px] after:w-14 after:bg-gold">
                    {{ 'cgv.title'|trans|raw }}
                </h1>
                <p class="mt-5 text-sm leading-7 text-dark/70 sm:text-base">
                    Merci de lire attentivement les presentes modalites d'utilisation du present site avant de le parcourir.
                </p>
            </div>

            <div class="mx-auto max-w-4xl">
                <article class="space-y-6">
                    <section class="border border-gold/20 bg-white p-6 shadow-[0_30px_80px_-45px_rgba(17,17,17,0.45)] sm:p-8">
                        <div class="prose prose-sm max-w-none prose-headings:font-serif prose-headings:uppercase prose-headings:tracking-[0.08em] prose-headings:text-dark prose-p:text-dark/80 prose-li:text-dark/80 prose-strong:text-dark prose-a:text-gold">
                            {% if contact.cgv %}
                                {{ contact.cgv|raw }}
                            {% endif %}
                        </div>
                    </section>

                    {% if contact.committeeChampagneSiret or contact.committeeChampagneIdentifiant %}
                        <section class="border border-gold/20 bg-white p-6 shadow-[0_30px_80px_-45px_rgba(17,17,17,0.45)] sm:p-8">
                            <h2 class="font-serif text-2xl uppercase tracking-[0.08em] text-dark">
                                Loi AGEC
                            </h2>
                            <div class="mt-6 space-y-3 text-sm leading-7 text-dark/80">
                                {% if contact.committeeChampagneSiret %}
                                    <p>Notre numero d'identifiant unique delivre par l'ADEME, conformement aux dispositions de la loi AGEC, est le suivant :</p>
                                    <p><strong>Ressortissant du Comite de Champagne :</strong> {{ contact.committeeChampagneSiret }}</p>
                                {% endif %}
                                {% if contact.committeeChampagneIdentifiant %}
                                    <p><strong>Titulaire de l'identifiant unique :</strong> {{ contact.committeeChampagneIdentifiant }}</p>
                                {% endif %}
                            </div>
                        </section>
                    {% endif %}
                </article>
            </div>
        </div>
    </section>
{% endblock %}
