<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Behavior;

use CpCreation\VitiCore\Media\Model\File;

interface HasFile
{
    public function getFile(): ?File;

    public function setFile(?File $file): void;
}
