{% extends '@CpCreationVitiCore/admin/base.html.twig' %}

{% block content %}
    <div class="panel panel-default">
        <div class="panel-heading">
            Cartes cadeaux
        </div>
        <table class="table table-striped dataTable">
            <thead>
            <tr>
                <th>#</th>
                <th>Nom</th>
                <th>Token</th>
                <th>Type</th>
                <th>Valide jusqu'au</th>
                <th>Date d'utilisation</th>
                <th>Action</th>
            </tr>
            </thead>
            <tbody>
            {% for item in gifts %}
                <tr class="{% if item.usedAt != null or "now"|format_date(locale=app.request.locale) > item.validUntilDate|format_date(locale=app.request.locale) %}danger{% endif %}">
                    <td>{{ loop.index }}</td>
                    <td>{{ item.cartItem.cart.lastname }} - {{ item.cartItem.cart.firstname }}</td>
                    <td>{{ item.token }}</td>
                    <td>{{ item.cartItem.variant.type.name }} - {{ item.cartItem.price/100 }}€</td>
                    <td>{{ item.validUntilDate|format_date(locale=app.request.locale) }}</td>
                    {% if(item.usedAt != null) %}
                        <td>{{ item.usedAt|format_date(locale=app.request.locale) }}</td>

                    {% else %}
                        <td></td>
                    {% endif %}
                    {% if item.usedAt != null or "now"|format_date(locale=app.request.locale) > item.validUntilDate|format_date(locale=app.request.locale) %}
                        <td></td>
                    {% else %}
                        <td>
                            <a href="{{ path('admin_gift_disable', { id: item.id }) }}"
                               class=" btn btn-default btn-xs" data-toggle="tooltip"
                               title="Utiliser la carte cadeau {{ item.token }}"><i
                                        class="fas fa-circle fa-2x color_green"></i></a>
                        </td>
                    {% endif %}
                </tr>
            {% endfor %}
            </tbody>
        </table>
    </div>
{% endblock %}
