<div {{ attributes.defaults({ class: 'z-10 mt-auto flex flex-wrap gap-3' }) }}>
    {% for award in product.awards %}
        {% if award.image and award.image.path %}
            <button
                type="button"
                class="block cursor-pointer transition hover:scale-105"
                data-action="live#action"
                data-live-action-param="showAwardModal"
                data-live-award-id-param="{{ award.id.toString }}"
            >
                <twig:Image
                    alt="{{ award.title ?? product.name|striptags }}"
                    class="w-24"
                    img:class="h-full w-full object-contain"
                    lazy="{{ false }}"
                    quality="{{ 50 }}"
                    responsive="{{ false }}"
                    path="{{ award.image.path }}"
                    imageWidth="200"
                    imageHeight="200"
                />
            </button>
        {% endif %}
    {% endfor %}
</div>
