<?php

/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Gite\Repository;

use CpCreation\VitiCore\Gite\Model\GiteImage;
use CpCreation\VitiCore\Repository\BaseRepository;
use Doctrine\Persistence\ManagerRegistry;

class GiteImageRepository extends BaseRepository
{
    /**
     * @throws \ReflectionException
     */
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, GiteImage::class);
    }
}
