<turbo-stream action="append" targets="#alert">
    <template>
        <div>
            <twig:Notification
                message="{{ message }}"
                level="{{ level }}"
                class="animate-toast flex w-full max-w-xs items-center rounded-lg bg-gray-800 p-4 text-gray-100 shadow dark:bg-gray-950 dark:text-gray-200"
                wrapper:class="inline-flex items-center justify-center flex-shrink-0 text-{{ level }} rounded-lg icon-{{ level }}"
                message:class="ml-3 text-sm font-bold"
                close:class="hover:text-dark -mx-1.5 -my-1.5 ml-auto inline-flex h-8 w-8 cursor-pointer p-1.5 text-white">
            </twig:Notification>
        </div>
    </template>
</turbo-stream>
