Nouvelle prise de contact depuis le site {{ company }}.

Nom : {{ data.firstname|default('') }} {{ data.lastname|default('') }}
Email : {{ data.email|default('Non renseigné') }}
Téléphone : {{ data.phone|default('Non renseigné') }}
Objet : {{ data.object|default('Non renseigné') }}

Message :
{{ data.message|default('') }}
