<?php

/*
 * This file is part of the VITICORE2 package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace CpCreation\VitiCore\Cart;

final class CartShipping
{
    public function __construct(
        public readonly int $amountTTC,
        public readonly float $taxRate,
        public readonly ?string $name = null,
    ) {
    }
}
