<?php

declare(strict_types=1);

namespace CpCreation\VitiCore\Cart\Model\Payment;

class Cawl
{
    private ?string $name = null;
    private ?string $subtitle = null;
    private bool $production = false;
    private ?string $pspid = null;
    private ?string $apiKey = null;
    private ?string $apiSecret = null;
    private ?string $webhookKey = null;
    private ?string $webhookSecret = null;

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): void
    {
        $this->name = $name;
    }

    public function getSubtitle(): ?string
    {
        return $this->subtitle;
    }

    public function setSubtitle(?string $subtitle): void
    {
        $this->subtitle = $subtitle;
    }

    public function isProduction(): bool
    {
        return $this->production;
    }

    public function setProduction(bool $production): void
    {
        $this->production = $production;
    }

    public function getPspid(): ?string
    {
        return $this->pspid;
    }

    public function setPspid(string $pspid): void
    {
        $this->pspid = $pspid;
    }

    public function getApiKey(): ?string
    {
        return $this->apiKey;
    }

    public function setApiKey(string $apiKey): void
    {
        $this->apiKey = $apiKey;
    }

    public function getApiSecret(): ?string
    {
        return $this->apiSecret;
    }

    public function setApiSecret(string $apiSecret): void
    {
        $this->apiSecret = $apiSecret;
    }

    public function getWebhookKey(): ?string
    {
        return $this->webhookKey;
    }

    public function setWebhookKey(string $webhookKey): void
    {
        $this->webhookKey = $webhookKey;
    }

    public function getWebhookSecret(): ?string
    {
        return $this->webhookSecret;
    }

    public function setWebhookSecret(string $webhookSecret): void
    {
        $this->webhookSecret = $webhookSecret;
    }
}
