{% block craue_flow_stepList_class %}
    {%- if loop.index == flow.getCurrentStepNumber() -%}
        {{ ' class="active"' }}
    {%- elseif flow.isStepSkipped(loop.index) -%}
        {{ ' class="craue_formflow_skipped_step"' }}
    {%- elseif flow.isStepDone(loop.index) -%}
        {{ ' class="complete"' }}
    {%- endif -%}
{% endblock %}

{% block craue_flow_stepLabel %}
    <span class="step">{{ loop.index }}</span> <span class="title"> {{- stepLabel | trans -}}</span>

{% endblock %}
{% block craue_flow_titleStep %}



{% endblock %}