{% extends '@CpCreationVitiCore/admin/base.html.twig' %}

{% block content %}
    <div class="panel panel-default grid-container">
        <div class="panel-heading">
            Associer votre compte instagram
        </div>
        <div class="panel-body text-center">
            {% if result == "error" %}
                <p>Vous avez annulé la demande d'autorisation pour récupérer votre contenu instagram, vous devez recommencer le processus.</p>
                <hr>
            {% endif %}
            {% if socialNetwork is null %}
                <a class="btn-social btn-insta" target="_blank"
                   href="{{ path('admin_socialNew_instagram_login') }}">
                    <i class="fab fa-instagram"></i>
                    <span>instagram</span>
                </a>
                <p>Vous devez autoriser CP Création a accéder à votre contenu instagram pour pouvoir l'afficher sur
                    votre site internet.</p>
            {% else %}
                <h2>Bonjour </h2>
                <img src="#" class="insta-photo" data-username="{{ socialNetwork.username }}"/>
                <h4>{{ socialNetwork.username }}</h4>
                <p> Votre compte instagram est bien associé à votre site internet</p>
                <div class="row">
                    {% if is_granted('ROLE_ADMIN') == true %}
                        <a class="btn btn-primary">Rafraichir le Token</a>
                    {% endif %}
                </div>
                <div class="row">
                    <div class="sm-col-6">
                        <a href="{{ path('admin_socialNew_delete', { id: socialNetwork.id}) }}"
                           class="btn btn-danger">Se déconnecter</a>
                    </div>
                </div>
            {% endif %}
        </div>
    </div>
{% endblock %}
