<?php

namespace CpCreation\VitiCore\Behavior;

use CpCreation\VitiCore\Media\Model\Image;

interface HasImage
{
    public function getImage(): ?Image;

    public function setImage(?Image $image): void;
}
