
    {% if not form.vars.valid %}
        <div class="alert alert-danger alert-dismissible" role="alert">
            <h5>Les erreurs a corriger !</h5>
            {% if not form.vars.valid %}
                <ul class="list-error">
                    {% for error in form.vars.errors %}
                        <span class="title-error">{{ (error.origin.config.name)|trans([]) }}</span>
                        <li>{{ error.message }}</li>
                    {% endfor %}
                </ul>
            {% endif %}
            {% for children in form.children %}
                {% if not children.vars.valid %}
                    <span class="title-error"> {{ (children.vars.name)|trans([]) }}</span>
                    <ul>
                        {% for error in children.vars.errors.form.getErrors(true) %}
                            <li>{{ error.message }}</li>
                        {% endfor %}
                    </ul>
                {% endif %}
            {% endfor %}
        </div>
    {% endif %}

<div class="row">
    <div class="col-md-12">
        <div class="panel panel-info">
            <div class="panel-heading">
                Intitulé de la méthode de livraison
            </div>
            <div class="panel-body">
                {{ form_row(form.translations) }}

            </div>
        </div>
    </div>

</div>
<div class="row">
    <div class="col-md-6">
        <div class="panel panel-info">
            <div class="panel-heading">
                Dates de publication
            </div>
            <div class="panel-body">
                {{ form_row(form.publishedAt) }}
                {{ form_row(form.unPublishedAt) }}
            </div>
            <div class="panel-heading">
                Catégorie
            </div>
            <div class="panel-body">
                {{ form_row(form.category) }}
            </div>
        </div>
    </div>
    <div class="col-md-6">
        <div class="panel panel-info">
            <div class="panel-heading">
                Prix de la livraison
            </div>
            <div class="panel-body">
                {{ form_row(form.enabledShippingPrice) }}
                {{ form_row(form.packagePrice) }}
                {{ form_row(form.bottlePrice) }}
                {{ form_row(form.disabledEquivalence) }}
                {{ form_row(form.qtyAt) }}
                {{ form_row(form.multipleVariant) }}
            </div>
        </div>
    </div>
</div>
<div class="row">
    <div class="col-md-6">
        <div class="panel panel-info">
            <div class="panel-heading">
                Groupes de prix
            </div>
            <div class="panel-body">
                {{ form_row(form.groups) }}
            </div>
        </div>
    </div>
    <div class="col-md-6">
        <div class="panel panel-info">
            <div class="panel-heading">
                Départements
            </div>
            <div class="panel-body">
                {{ form_row(form.counties) }}
                {{ form_row(form.viewCounties) }}
            </div>
        </div>
    </div>
</div>
<div class="row">
    <div class="col-md-12">
        <div class="panel panel-info">
            <div class="panel-heading">
                Produits
            </div>
            <div class="panel-body">
                <div class="row">
                    <div class="col-md-12"> {{ form_row(form.productVariants) }}</div>
                    <div class="col-md-12"> {{ form_row(form.viewProduct) }}</div>
                    <div class="col-md-12"> {{ form_row(form.depot) }}</div>
                </div>
            </div>
        </div>
    </div>
</div>
{{ form_rest(form) }}
