
    {% if not form.vars.valid %}
        <div class="alert alert-danger alert-dismissible" role="alert">
            <h5>Les erreurs a corriger !</h5>
            {% if not form.vars.valid %}
                <ul class="list-error">
                    {% for error in form.vars.errors %}
                        <span class="title-error">{{ (error.origin.config.name)|trans([]) }}</span>
                        <li>{{ error.message }}</li>
                    {% endfor %}
                </ul>
            {% endif %}
            {% for children in form.children %}
                {% if not children.vars.valid %}
                    <span class="title-error"> {{ (children.vars.name)|trans([]) }}</span>
                    <ul>
                        {% for error in children.vars.errors.form.getErrors(true) %}
                            <li>{{ error.message }}</li>
                        {% endfor %}
                    </ul>
                {% endif %}
            {% endfor %}
        </div>
    {% endif %}

{% if is_granted('ROLE_ADMIN') or is_granted('ROLE_PRODUCT') %}
    <div class="row trumbowyg-min">
        <div class="col-md-12">
            <div class="panel panel-info">
                <div class="panel-heading">
                    Nom & Description
                </div>
                <div class="panel-body">
                    {{ form_row(form.translations) }}
                </div>
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="panel panel-info">
                <div class="panel-heading">
                    Category
                </div>
                <div class="panel-body">
                    <div class="row">
                        <div class="col-md-12"> {{ form_row(form.category) }}</div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="panel panel-info">
                <div class="panel-heading">
                    Image Cuvée
                </div>
                <div class="panel-body">
                    {{ form_row(form.image) }}
                </div>
            </div>
            <div class="panel panel-info">
                <div class="panel-heading">
                    Images supplémentaires dans le panel dans la boutique
                </div>
                <div class="panel-body">
                    {{ form_row(form.images) }}
                </div>
            </div>
            <div class="panel panel-info">
                <div class="panel-heading">
                    Fichier unique
                </div>
                <div class="panel-body">
                    {{ form_row(form.file) }}
                </div>
            </div>
           {# <div class="panel panel-info">
                <div class="panel-heading">
                    Fichier par langue
                </div>
                <div class="panel-body">
                    {{ form_row(form.files) }}
                </div>
            </div>#}

            <div class="panel panel-info">
                <div class="panel-heading">
                    Récompenses
                </div>
                <div class="panel-body">
                    {{ form_row(form.awards) }}
                </div>
            </div>

        </div>
        <div class="col-md-6">
            <div class="panel panel-info">
                <div class="panel-heading">
                    Image Boutique
                </div>
                <div class="panel-body">
                    {{ form_row(form.secondImage) }}
                </div>
            </div>
            <div class="panel panel-info">
                <div class="panel-heading">
                    Image Background
                </div>
                <div class="panel-body">
                    {{ form_row(form.backgroundImage) }}
                </div>
            </div>

            <div class="panel panel-info">
                <div class="panel-heading">
                    Afficher
                </div>
                <div class="panel-body">
                    {{ form_row(form.enableColor) }}
                    {{ form_row(form.enableColorQuality) }}
                    {{ form_row(form.color) }}
                    {{ form_row(form.colorGradient1) }}
                    {{ form_row(form.colorGradient2) }}
                    {{ form_row(form.disabled) }}
                    {{ form_row(form.cuvee) }}
                    {{ form_row(form.shop) }}
                    {{ form_row(form.new) }}
                    {{ form_row(form.soldOut) }}
                    {{ form_row(form.ribbonCustomColor) }}
                    {{ form_row(form.favorite) }}
                    {{ form_row(form.orderInFavorites) }}
                    {{ form_row(form.groups) }}
                    {{ form_row(form.referenceToken) }}
                </div>
            </div>

        </div>
    </div>
{% endif %}
<div class="row">
    <div class="col-md-12">
        <div class="panel panel-info">
            <div class="panel-heading">
                Variations du produit
            </div>
            <div class="panel-body">
                {{ form_row(form.variants) }}
            </div>
        </div>
    </div>
</div>
{{ form_rest(form) }}
