
    {% if not form.vars.valid %}
        <div class="alert alert-danger alert-dismissible" role="alert">
            <h5>Les erreurs a corriger !</h5>
            {% if not form.vars.valid %}
                <ul class="list-error">
                    {% for error in form.vars.errors %}
                        <span class="title-error">{{ (error.origin.config.name)|trans([]) }}</span>
                        <li>{{ error.message }}</li>
                    {% endfor %}
                </ul>
            {% endif %}
            {% for children in form.children %}
                {% if not children.vars.valid %}
                    <span class="title-error"> {{ (children.vars.name)|trans([]) }}</span>
                    <ul>
                        {% for error in children.vars.errors.form.getErrors(true) %}
                            <li>{{ error.message }}</li>
                        {% endfor %}
                    </ul>
                {% endif %}
            {% endfor %}
        </div>
    {% endif %}

<div class="row">
    <div class="col-md-6">
        <div class="panel panel-info">
            <div class="panel-heading">
                Offrir frais de port + Marge Banque
            </div>
            <div class="panel-body">
                {{ form_row(form.amountFreeShipping) }}
                {{ form_row(form.marginBank) }}
                {{ form_row(form.amountMarginBank) }}
                {{ form_row(form.qtyEquivalencyBottle) }}
                {% if is_granted('ROLE_ADMIN') %}
                    {{ form_row(form.forceEquivalencyForAuto) }}
                {% endif %}
            </div>
        </div>
        <div class="panel panel-info">
            <div class="panel-heading">
                Texte
            </div>
            <div class="panel-body">
                {{ form_row(form.translations) }}
            </div>
        </div>
        {% if is_granted('ROLE_ADMIN') %}
            <div class="panel panel-info">
                <div class="panel-heading">
                    Informations fichiers transporteur
                </div>
                <div class="panel-body">
                    Convertir XLS en XLSX sinon erreur 500.

                    Géodis: 2 fichiers
                    <ul>
                        <li>
                            Fichier transporteur : TARIF 615 - 2018 .xls ( à convertir en xlsx en ligne par exemple )
                        </li>
                        <li>
                            Fichier transporteur (Haute montagne) : Localités spécifiques 2018.xlsx
                        </li>
                    </ul>
                    Oenotrans: 1 fichier avec 2 feuilles excel
                    <ul>
                        <li>
                            Fichier transporteur : Oenotrans Tarif TSMMYY .xlsx
                        </li>
                        <li>
                            Fichier transporteur (Haute montagne) : Oenotrans Tarif TSMMYY .xlsx
                        </li>
                    </ul>
                    TCP ( Oenotrans ): 1 fichier avec 3 feuilles excel
                    <ul>
                        <li>
                            Convertir en XLSX
                        </li>
                        <li>
                            Fichier transporteur : 2019.06. TCP-Oenotrans Tarifs V.I DPT 51.xls
                        </li>
                        <li>
                            Fichier transporteur (Haute montagne) : Le même fichier que le fichier Transporteur
                        </li>
                    </ul>
                    Transvins: 2 fichiers
                    <ul>
                        <li>
                            Fichier transporteur : Iles et Hautes Montagnes.xlsx
                        </li>
                        <li>
                            Fichier transporteur (Haute montagne) : Liste Ile et Haute Montagne.xlsx
                        </li>
                    </ul>
                    Scellier: 1 fichier
                    <ul>
                        <li>
                            Fichier transporteur : TARIFS CHAMPAGNE 2020 AISNE ( exemple de nom de fichier de ce transporteur)
                        </li>
                        <li>
                            Fichier transporteur (Haute montagne) : Prendre le fichier de transvins
                        </li>
                    </ul>
                </div>
            </div>
        {% endif %}
        {% if is_granted('ROLE_ADMIN') %}
            <div class="panel panel-info">
                <div class="panel-heading">
                    Informations transporteur & Taxe
                </div>
                <div class="panel-body">
                    <p><strong>Le Minimum de perception de Taxe Valeur Déclarée</strong> va de paire avec <strong>le
                            pourcentage par rapport à la valeur déclarée</strong>. Le montant est calculé par rapport au
                        montant
                        du panier. La taxe gazole est calculée après l'ajout de cette Taxe (Oenotrans, Géodis)</p>
                    <p><strong>Oenotrans et TCP : </strong></p>
                    <p>Oenotrans et TCP ajoute les frais de port et les différentes taxes avant le calcul de la Taxe Gazole
                        !</p>
                    <p><strong>Transvins : </strong></p>
                    <p>Tous les frais de transports sont inclus dans le tableau des tarifs de Transvins, si pas
                        d'assurances
                        prises ( non obligatoire ).
                    </p>
                    <p><strong>Logivin : </strong></p>
                    <p>Tous les frais de transports sont inclus dans le tableau des tarifs de Logivin, si pas
                        d'assurances
                        prises ( non obligatoire ). </p>
                    <p><strong>Géodis : </strong></p>
                    <p>Voir le tableau de Géodis car plein de petit frais à ajouter. </p>
                    <p><strong>Scellier : </strong></p>
                    <p>Ajouter la surtaxe Paris + la taxe de sureté + la taxe de frais de facturation . </p>
                </div>
            </div>
        {% endif %}
    </div>
    <div class="col-md-6">
        {% if is_granted('ROLE_ADMIN') %}
            <div class="panel panel-info">
                <div class="panel-heading">
                    Configuration du mode Manu
                </div>
                <div class="panel-body">
                    {{ form_row(form.amountFixedManu) }}
                    {{ form_row(form.amountMinVDManu) }}
                    {{ form_row(form.qtyMinVDManu) }}
                    {{ form_row(form.marginManu) }}
                    {{ form_row(form.marginClientManu) }}
                    {{ form_row(form.tvaManu) }}
                    {{ form_row(form.amountByBottleTTC) }}
                </div>
            </div>
        {% endif %}
        <div class="panel panel-info">
            <div class="panel-heading">
                Configuration du mode Auto
            </div>
            <div class="panel-body">
                {% if is_granted('ROLE_ADMIN') %}
                    {{ form_row(form.amountMinVDAuto) }}
                    {{ form_row(form.amountVDAuto) }}
                    {{ form_row(form.amountPercentVDAuto) }}
                    {{ form_row(form.qtyMinVDAuto) }}
                {% endif %}
                {{ form_row(form.amountFixedBeforeMargeAuto) }}
                {{ form_row(form.highMountainAmount) }}
                {{ form_row(form.marginAuto) }}
                {{ form_row(form.marginGazoleAuto) }}
                {{ form_row(form.marginClientAuto) }}
                {{ form_row(form.amountFixedAuto) }}
                {{ form_row(form.amountAutoByBottleTTC) }}
                {% if is_granted('ROLE_ADMIN') %}
                {{ form_row(form.carrier) }}
                {{ form_row(form.file) }}
                {% if item is defined %}
                <div class="row">
                    <div class="col-md-6">
                        <a href="{{ path('admin_shipping_config_price_delete', {id: item.id}) }}"
                           class="btn btn-danger">Supprimer frais de ports</a>
                    </div>
                </div>
                {% endif %}
                {{ form_row(form.fileSup) }}
                {% if item is defined %}
                <div class="col-md-6">
                    <a href="{{ path('admin_shipping_config_sup_delete',  {id: item.id}) }}"
                       class="btn btn-danger">Supprimer supplément villes</a>
                </div>
                {% endif %}
                {% endif %}
            </div>
        </div>
    </div>
</div>
{{ form_rest(form) }}
