<meta charset="UTF-8">
<title>{{ head_title|default('Welcome!') }}</title>
<link
  rel="icon"
  href="data:image/svg+xml,<svg xmlns=%22http://www.w3.org/2000/svg%22 viewBox=%220 0 128 128%22><text y=%221.2em%22 font-size=%2296%22>⚫️</text><text y=%221.3em%22 x=%220.2em%22 font-size=%2276%22 fill=%22%23fff%22>sf</text></svg>">

{{ head_meta|default('')|raw }}

{% if app.environment == 'dev' %}
  {{ encore_entry_link_tags("app", null, "front") }}
  {{ encore_entry_script_tags("app", null, "front") }}
{% else %}
  {% set scriptNonce = csp_nonce('script') %}
  {% set styleNonce = csp_nonce('style') %}
  {{ encore_entry_link_tags("app", null, "front", { nonce: styleNonce }) }}
  <meta name="csp-nonce" content="{{ scriptNonce }}">
  {{ encore_entry_script_tags("app", null, "front", { nonce: scriptNonce }) }}
{% endif %}

{{ head_stylesheets|default('')|raw }}
{{ head_javascripts|default('')|raw }}

<meta name="viewport" content="width=device-width, initial-scale=1.0">
<meta name="turbo-refresh-method" content="morph">
<meta name="turbo-cache-control" content="no-cache">
<meta name="view-transition" content="same-origin">
<meta name="x-window-id" content="{{ app.request.headers.get('X-Window-Id') }}">
<meta name="x-mer" content="{{ app.request.headers.get('x-mer') }}">
