<?php

namespace CpCreation\VitiCore\Behavior;

use CpCreation\VitiCore\Media\Model\Image;
use Doctrine\Common\Collections\Collection;

interface HasImages
{
    /**
     * @return Collection<int, Image>
     */
    public function getImages(): Collection;
}
