{% extends 'base.html.twig' %}
{% block title %}{{ 'security.register_confirm.title'|trans({}, 'meta') }}{% endblock %}
{% block meta %}
    <meta name="robots" content="noindex,nofollow">
    <meta name="description" lang="{{ app.request.locale }}" content="{{ 'security.register_confirm.description'|trans({}, 'meta') }}">
{% endblock meta %}
{% block main %}
    <div class="min-h-[calc(100vh-13rem)] bg-[#f7f2ea]">
        <div class="relative mx-auto flex max-w-2xl items-center justify-center px-4 py-10 sm:px-6 lg:min-h-[calc(100vh-13rem)] lg:px-8 lg:py-16">
            <section class="w-full bg-white p-5 shadow-[0_18px_45px_rgba(61,43,23,0.08)] sm:p-7 lg:p-8">
                <div class="bg-[#fcfaf7] p-5 sm:p-6">
                    <p class="text-xs uppercase tracking-[0.4em] text-[#9d7c47]">{{ 'security.register.submit'|trans }}</p>
                    <h1 class="mt-3 font-serif text-3xl text-[#201917]">{{ 'security.register_confirm.heading'|trans }}</h1>
                    <p class="mt-3 text-sm leading-6 text-[#5d4b41]">
                        {{ 'security.register_confirm.intro'|trans }}
                    </p>
                    {{ component('security:RegisterConfirmForm', {
                        email: pending_email,
                        marketingOptIn: pending_marketing_opt_in
                    }) }}
                </div>
            </section>
        </div>
    </div>
{% endblock %}
