<?php

declare(strict_types=1);

/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\SocialNetwork\Model\Network;

class FacebookInstagram
{
    private ?string $id = null;

    private ?string $name = null;

    private ?string $accountInstagram = null;

    public function getId(): ?string
    {
        return $this->id;
    }

    public function setId(?string $id): void
    {
        $this->id = $id;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(?string $name): void
    {
        $this->name = $name;
    }

    public function getAccountInstagram(): ?string
    {
        return $this->accountInstagram;
    }

    public function setAccountInstagram(?string $accountInstagram): void
    {
        $this->accountInstagram = $accountInstagram;
    }
}
