{% extends '@CpCreationVitiCore/admin/base.html.twig' %}

{% block content %}
    <h1 class="page-header">Nouveau type de produit</h1>
    <form action="{{ path('admin_product_type_new') }}" enctype="multipart/form-data" method="POST" novalidate>
        <div class="panel panel-default">
            <div class="panel-heading">
                <a href="{{path("admin_product_type")}}"><button type="button" class="btn btn-danger btn-rounded">{{ 'Annuler'|trans }}</button></a>
                <button type="submit" name="wave" class="btn btn-primary form-submit btn-rounded">{{ 'Enregistrer'|trans }}</button>
                <div class="clearfix"></div>
            </div>
        </div>
        {{ include('@CpCreationVitiCore/admin/product/type/_form.html.twig', {form: form }, with_context=false) }}
        <div class="panel panel-default">
            <div class="panel-heading">
                <a href="{{path("admin_product_type")}}"><button type="button" class="btn btn-danger btn-rounded">{{ 'Annuler'|trans }}</button></a>
                <button type="submit" name="wave" class="btn btn-primary form-submit btn-rounded">{{ 'Enregistrer'|trans }}</button>
                <div class="clearfix"></div>
            </div>
        </div>
    </form>
{% endblock %}
