<?php

/*
 * This file is part of the Serenity package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace CpCreation\VitiCore\Behavior;

interface HasAddress
{
    public function getLastname(): ?string;

    public function getFirstname(): ?string;

    public function getCompany(): ?string;

    public function getSiret(): ?string;

    public function getVatId(): ?string;

    public function getStreet(): ?string;

    public function getPhone(): ?string;

    public function getPostal(): ?string;

    public function getCity(): ?string;

    public function getCountry(): ?string;
}
