<?php

declare(strict_types=1);

namespace CpCreation\VitiCore\Cart\Model\Payment;

class BankTransfert
{
    private ?string $name = null;
    private ?string $subtitle = null;
    private ?string $text = null;

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): void
    {
        $this->name = $name;
    }

    public function getSubtitle(): ?string
    {
        return $this->subtitle;
    }

    public function setSubtitle(?string $subtitle): void
    {
        $this->subtitle = $subtitle;
    }

    public function getText(): ?string
    {
        return $this->text;
    }

    public function setText(string $text): void
    {
        $this->text = $text;
    }
}
