<?php

declare(strict_types=1);

namespace CpCreation\VitiCore\Cart\Model\Payment;

class SystemPay
{
    private ?string $name = null;
    private ?string $subtitle = null;
    private ?string $mode = null;
    private ?string $siteId = null;
    private ?string $key = null;
    private ?string $hmacAlgo = null;

    public function getHmacAlgo(): ?string
    {
        return $this->hmacAlgo;
    }

    public function setHmacAlgo(string $hmacAlgo): void
    {
        $this->hmacAlgo = $hmacAlgo;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): void
    {
        $this->name = $name;
    }

    public function getSubtitle(): ?string
    {
        return $this->subtitle;
    }

    public function setSubtitle(?string $subtitle): void
    {
        $this->subtitle = $subtitle;
    }

    public function getMode(): ?string
    {
        return $this->mode;
    }

    public function setMode(string $mode): void
    {
        $this->mode = $mode;
    }

    public function getSiteId(): ?string
    {
        return $this->siteId;
    }

    public function setSiteId(string $siteId): void
    {
        $this->siteId = $siteId;
    }

    public function getKey(): ?string
    {
        return $this->key;
    }

    public function setKey(string $key): void
    {
        $this->key = $key;
    }
}
