<?php

declare(strict_types=1);

/*
 * This file is part of the Serenity package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace CpCreation\VitiCore\Product;

use CpCreation\VitiCore\Product\DTO\DegressiveContext;
use CpCreation\VitiCore\Product\DTO\DegressiveResult;
use Symfony\Component\DependencyInjection\Attribute\AsDecorator;

#[AsDecorator(decorates: DegressiveCalculatorInterface::class, priority: -100)]
final class ApplyDegressiveToCartDecorator implements DegressiveCalculatorInterface
{
    public function __construct(
        private readonly DegressiveCalculatorInterface $inner,
    ) {
    }

    public function calculate(DegressiveContext $context): ?DegressiveResult
    {
        return $this->inner->calculate($context);
    }
}
