<?php

/*
 * This file is part of the VITICORE2 package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace CpCreation\VitiCore\Cart;


final readonly class CartPricingLine
{
    public function __construct(
        public ?string $itemId,
        public ?string $productId,
        public ?string $productName,
        public ?string $variantId,
        public ?string $variantFullName,
        public ?string $typeId,
        public ?string $typeName,
        public ?string $unitLabel,
        public ?string $imagePath,
        public int $quantity,
        public int $unitPriceHT,
        public int $unitPriceTTC,
        public ?int $unitPriceDiscountHT,
        public ?int $unitPriceDiscountTTC,
        public int $totalHT,
        public int $totalTTC,
        public int $totalDiscountTTC,
        public int $totalDiscountHT,
        public ?int $unitDegressiveTTC,
        public ?int $unitDegressiveHT,
        public int $degressiveTTC,
        public int $degressiveHT,
        public int $netTTC,
        public int $netHT,
        public int $tax,
        public bool $isPromoGift = false,
    ) {
    }
}
