{% extends 'base.html.twig' %}

{% block title %}{{ 'privacy_policy.title'|trans({}, 'meta') }}{% endblock %}

{% block meta %}
    {{ include('partials/seo.html.twig', {
        title_key: 'privacy_policy.title',
        description_key: 'privacy_policy.description',
        robots: 'noindex,nofollow'
    }) }}
{% endblock meta %}

{% block main %}
    <section class="pt-4 bg-light">
        <div class="mx-4 lg:mx-8 large:mx-auto max-w-large pb-20 pt-16 sm:pb-28 sm:pt-20">
            <div class="mx-auto mb-10 max-w-4xl px-6 text-center sm:px-8">
                <h1 class="flex flex-col items-center font-serif text-3xl uppercase tracking-[0.14em] text-dark sm:text-4xl lg:text-5xl after:mt-5 after:h-[2px] after:w-14 after:bg-gold">
                    {{ 'privacy_policy.title'|trans|raw }}
                </h1>
            </div>

            <div class="mx-auto max-w-4xl">
                <article class="space-y-6">
                    <section class="border border-gold/20 bg-white p-6 shadow-[0_30px_80px_-45px_rgba(17,17,17,0.45)] sm:p-8">
                        <h2 class="font-serif text-2xl uppercase tracking-[0.08em] text-dark">Introduction</h2>
                        <div class="mt-6 space-y-4 text-sm leading-7 text-dark/80">
                            <p>
                                Nous (« nous ») nous soucions de la vie privee des utilisateurs (l'« utilisateur » ou « vous ») de notre site Internet (le « Site ») et nous nous engageons a proteger les informations que les utilisateurs partagent avec nous lorsqu'ils utilisent notre Site, et a les utiliser conformement a la loi applicable.
                            </p>
                            <p>
                                Cette politique de confidentialite decrit nos pratiques en matiere de recueil, d'utilisation et de divulgation de vos informations lorsque vous accedez a nos services depuis votre appareil.
                            </p>
                            <p>
                                Avant d'acceder ou d'utiliser nos services, veuillez lire attentivement cette politique de confidentialite. En utilisant nos services, vous acceptez les conditions de cette politique et toute mise a jour qui y serait apportee.
                            </p>
                            <p>Dans la presente politique de confidentialite, vous trouverez des explications sur les questions suivantes :</p>
                            <ul class="space-y-2 pl-5 list-disc marker:text-gold">
                                <li>Les informations que nous recueillons</li>
                                <li>Comment nous recueillons les informations</li>
                                <li>Pourquoi nous recueillons les informations</li>
                                <li>Avec qui nous partageons les informations</li>
                                <li>Ou sont stockees les informations</li>
                                <li>Combien de temps elles sont conservees</li>
                                <li>Comment nous protegeoins les informations</li>
                                <li>Modifications ou mises a jour de la politique de confidentialite</li>
                            </ul>
                        </div>
                    </section>

                    <section class="border border-gold/20 bg-white p-6 shadow-[0_30px_80px_-45px_rgba(17,17,17,0.45)] sm:p-8">
                        <h2 class="font-serif text-2xl uppercase tracking-[0.08em] text-dark">Les informations que nous recueillons</h2>
                        <div class="mt-6 space-y-4 text-sm leading-7 text-dark/80">
                            <p>
                                Nous recueillons des informations non identifiees et non identifiables, composees principalement d'informations techniques et d'utilisation agregees.
                            </p>
                            <p>
                                Nous pouvons egalement recueillir des informations personnelles permettant de vous identifier, comme le nom, le prenom, l'adresse e-mail, le numero de telephone, l'adresse IP ou toute autre information demandee lorsque cela est necessaire.
                            </p>
                        </div>
                    </section>

                    <section class="border border-gold/20 bg-white p-6 shadow-[0_30px_80px_-45px_rgba(17,17,17,0.45)] sm:p-8">
                        <h2 class="font-serif text-2xl uppercase tracking-[0.08em] text-dark">Comment nous recueillons les informations</h2>
                        <div class="mt-6 space-y-4 text-sm leading-7 text-dark/80">
                            <p>
                                Nous recueillons des informations lorsque vous utilisez les services. Lorsque vous visitez nos proprietes numeriques, nous pouvons enregistrer vos usages, sessions et informations connexes.
                            </p>
                            <p>
                                Nous recueillons egalement les informations que vous nous fournissez volontairement, par exemple lorsque vous nous contactez directement par un canal de communication.
                            </p>
                        </div>
                    </section>

                    <section class="border border-gold/20 bg-white p-6 shadow-[0_30px_80px_-45px_rgba(17,17,17,0.45)] sm:p-8">
                        <h2 class="font-serif text-2xl uppercase tracking-[0.08em] text-dark">Pourquoi nous recueillons les informations</h2>
                        <ul class="mt-6 space-y-2 pl-5 text-sm leading-7 text-dark/80 list-disc marker:text-gold">
                            <li>Pour developper, personnaliser et ameliorer nos services</li>
                            <li>Pour repondre a vos demandes et vous apporter notre assistance</li>
                            <li>Pour analyser les schemas de demande et d'utilisation</li>
                            <li>Pour des finalites internes, de recherche ou de statistiques</li>
                        </ul>
                    </section>

                    <section class="border border-gold/20 bg-white p-6 shadow-[0_30px_80px_-45px_rgba(17,17,17,0.45)] sm:p-8">
                        <h2 class="font-serif text-2xl uppercase tracking-[0.08em] text-dark">Avec qui nous partageons les informations</h2>
                        <div class="mt-6 space-y-4 text-sm leading-7 text-dark/80">
                            <p>
                                Nous pouvons partager vos informations avec nos fournisseurs de services afin d'exploiter nos services, notamment Google pour le suivi statistique de notre site internet et Axeptio pour la gestion des consentements de cookies.
                            </p>
                            <p>
                                Nous ne partageons pas votre adresse e-mail ni toute autre information personnelle avec des societes de publicite en ligne ou des reseaux publicitaires sans votre consentement.
                            </p>
                        </div>
                    </section>

                    <section class="border border-gold/20 bg-white p-6 shadow-[0_30px_80px_-45px_rgba(17,17,17,0.45)] sm:p-8">
                        <h2 class="font-serif text-2xl uppercase tracking-[0.08em] text-dark">Cookies</h2>
                        <p class="mt-6 text-sm leading-7 text-dark/80">
                            Lorsque vous visitez ou accedez a notre service, certains tiers peuvent utiliser des cookies, balises web, pixels invisibles, scripts et autres technologies de suivi afin d'ameliorer votre navigation, les performances du site, votre experience utilisateur ainsi que la securite et la prevention de la fraude.
                        </p>
                    </section>

                    <section class="border border-gold/20 bg-white p-6 shadow-[0_30px_80px_-45px_rgba(17,17,17,0.45)] sm:p-8">
                        <h2 class="font-serif text-2xl uppercase tracking-[0.08em] text-dark">Ou sont stockees les informations</h2>
                        <div class="mt-6 space-y-4 text-sm leading-7 text-dark/80">
                            <p>
                                Les informations non personnelles peuvent etre stockees et traitees dans diverses juridictions a travers le monde par nos partenaires et fournisseurs de services.
                            </p>
                            <p>
                                Les informations personnelles sont conservees, traitees et stockees en France metropolitaine.
                            </p>
                        </div>
                    </section>

                    <section class="border border-gold/20 bg-white p-6 shadow-[0_30px_80px_-45px_rgba(17,17,17,0.45)] sm:p-8">
                        <h2 class="font-serif text-2xl uppercase tracking-[0.08em] text-dark">Combien de temps les informations sont conservees</h2>
                        <p class="mt-6 text-sm leading-7 text-dark/80">
                            Nous conservons les informations aussi longtemps que necessaire pour fournir les services et pour nous conformer a nos obligations legales ou contractuelles, resoudre les litiges et faire respecter nos accords. Nous pouvons corriger, completer ou supprimer des informations incompletes ou inexactes a tout moment.
                        </p>
                    </section>

                    <section class="border border-gold/20 bg-white p-6 shadow-[0_30px_80px_-45px_rgba(17,17,17,0.45)] sm:p-8">
                        <h2 class="font-serif text-2xl uppercase tracking-[0.08em] text-dark">Comment nous protegeoins les informations</h2>
                        <p class="mt-6 text-sm leading-7 text-dark/80">
                            Le service d'hebergement de nos proprietes numeriques met a notre disposition la plateforme en ligne qui nous permet de vous fournir le service. Vos donnees peuvent etre stockees par l'intermediaire des applications de stockage, des bases de donnees ou de l'infrastructure generale de notre hebergeur, sur des serveurs securises derriere un pare-feu et avec un acces HTTPS.
                        </p>
                    </section>

                    <section class="border border-gold/20 bg-white p-6 shadow-[0_30px_80px_-45px_rgba(17,17,17,0.45)] sm:p-8">
                        <h2 class="font-serif text-2xl uppercase tracking-[0.08em] text-dark">Modifications ou mises a jour</h2>
                        <p class="mt-6 text-sm leading-7 text-dark/80">
                            Nous pouvons reviser cette politique de confidentialite a tout moment. La version la plus recente est toujours affichee sur notre site. Nous vous encourageons a la consulter regulierement. En continuant a utiliser les services apres publication d'une mise a jour, vous reconnaissez et acceptez ces modifications.
                        </p>
                    </section>

                    <section class="border border-gold/20 bg-white p-6 shadow-[0_30px_80px_-45px_rgba(17,17,17,0.45)] sm:p-8">
                        <h2 class="font-serif text-2xl uppercase tracking-[0.08em] text-dark">Nous contacter</h2>
                        <p class="mt-6 text-sm leading-7 text-dark/80">
                            Si vous avez des questions d'ordre general sur les services ou les informations que nous recueillons, contactez-nous a l'aide de notre formulaire de contact.
                        </p>
                    </section>
                </article>
            </div>
        </div>
    </section>
{% endblock %}
