<?php

declare(strict_types=1);

namespace CpCreation\VitiCore\Bridge\Doctrine\Migrations;

use Doctrine\DBAL\Schema\Schema;
use Doctrine\Migrations\AbstractMigration;

final class Version20260427143000 extends AbstractMigration
{
    public function getDescription(): string
    {
        return 'Ajoute la zone d’affichage des blocs d’information boutique';
    }

    public function up(Schema $schema): void
    {
        $this->addSql("ALTER TABLE shop_information_block ADD display_zone VARCHAR(10) DEFAULT 'top' NOT NULL");
    }

    public function down(Schema $schema): void
    {
        $this->addSql('ALTER TABLE shop_information_block DROP display_zone');
    }
}
