<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Bridge\Symfony\Bundle\Validator\Constraints;

use Symfony\Component\Validator\Constraint;

#[\Attribute]
class Translation extends Constraint
{
    public string $message = 'Vous devez entrer certaines valeurs pour la langue {{ string }}';

    public function validatedBy(): string
    {
        return static::class . 'Validator';
    }
}
