<?php

/*
 * This file is part of the VitiCore 2.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace CpCreation\VitiCore\Bridge\Symfony\Bundle\Form\Admin;

use A2lix\TranslationFormBundle\Form\Type\TranslatedEntityType;
use CpCreation\VitiCore\Cart\Model\Promo;
use CpCreation\VitiCore\Product\Model\Product;
use CpCreation\VitiCore\Product\Model\ProductPriceGroup;
use CpCreation\VitiCore\Product\Model\ProductVariant;
use CpCreation\VitiCore\Product\Repository\ProductPriceGroupRepository;
use CpCreation\VitiCore\Shop\Model\ShippingZone;
use CpCreation\VitiCore\User\Model\User;
use CpCreation\VitiCore\User\Repository\UserRepository;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\DateTimeType;
use Symfony\Component\Form\Extension\Core\Type\EmailType;
use Symfony\Component\Form\Extension\Core\Type\IntegerType;
use Symfony\Component\Form\Extension\Core\Type\MoneyType;
use Symfony\Component\Form\Extension\Core\Type\NumberType;
use Symfony\Component\Form\Extension\Core\Type\PercentType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

final class PromoType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder
            ->add('title', TextType::class, ['label' => 'Code promo', 'required' => true])
            ->add(
                'minEquivalency', IntegerType::class, [
                    'required' => false,
                    'label' => 'Quantité minimum de commande (équivalence bouteille)',
                ]
            )
            ->add(
                'maxEquivalency', IntegerType::class, [
                    'required' => false,
                    'label' => 'Quantité maximum de commande (équivalence bouteille)',
                ]
            )
            ->add(
                'percent', PercentType::class, [
                    'required' => false,
                    'label' => 'Remise pourcentage sur le montant du panier',
                ]
            )
            ->add(
                'percentShippingCost', PercentType::class, [
                    'required' => false,
                    'label' => 'Remise pourcentage sur le montant du transport',
                ]
            )
            ->add(
                'amount', MoneyType::class, [
                    'divisor' => 100,
                    'required' => false,
                    'label' => 'Remise en euros',
                ]
            )
            ->add(
                'minSubtotalTTC', MoneyType::class, [
                    'divisor' => 100,
                    'required' => false,
                    'label' => 'Montant minimum du panier TTC',
                    'help' => 'Laisser vide pour ne pas conditionner la promo au montant du panier.',
                ]
            )
            ->add(
                'maxCount', NumberType::class, [
                    'required' => false,
                    'html5' => true,
                    'label' => 'Limiter le nombre d\'utilisation de ce code (dans l\'absolue)',
                ]
            )
            ->add(
                'maxCountByCustomer', NumberType::class, [
                    'required' => false,
                    'html5' => true,
                    'label' => 'Limiter le nombre d\'utilisation de ce code par utilisateur',
                ]
            )
            ->add(
                'beginAt', DateTimeType::class, [
                    'required' => true,
                    'label' => 'Date de début',
                    'input' => 'datetime',
                    'format' => 'yyyy-MM-dd HH:mm',
                    'html5' => false,
                    'widget' => 'single_text',
                    'attr' => [
                        'class' => 'datetimepicker',
                    ],
                ]
            )
            ->add(
                'endAt', DateTimeType::class, [
                    'required' => true,
                    'label' => 'Date de fin',
                    'input' => 'datetime',
                    'format' => 'yyyy-MM-dd HH:mm',
                    'html5' => false,
                    'widget' => 'single_text',
                    'attr' => [
                        'class' => 'datetimepicker',
                    ],
                ]
            )
            ->add(
                'disabled', ChoiceType::class, [
                    'required' => true,
                    'label' => 'Publier',
                    'choices' => [
                        'Oui' => false,
                        'Non' => true,
                    ],
                ]
            )
            ->add(
                'auto', CheckboxType::class, [
                    'required' => false,
                    'label' => 'Mode auto (pas besoin d\'entrer un code)',
                    'help' => 'Possible pour une promo générale ou liée à un client enregistré. Impossible si seule une adresse email est renseignée.',
                ]
            )
            ->add(
                'cumulative', CheckboxType::class, [
                    'required' => false,
                    'label' => 'Cumulable avec d\'autres promos auto',
                    'help' => 'Si décoché, cette promo auto sera retenue seulement si son gain dépasse le total des promos auto cumulables applicables.',
                ]
            )
            ->add(
                'incompatibleAutoPromos', EntityType::class, [
                    'class' => Promo::class,
                    'query_builder' => static fn ($repository) => $repository->createAutoPromoSelectionQueryBuilder(),
                    'choice_label' => static fn (Promo $promo): string => (string) ($promo->getTitle() ?? $promo->getId()->toString()),
                    'label' => 'Promos auto non cumulables avec celle-ci',
                    'required' => false,
                    'multiple' => true,
                    'help' => 'Sélectionnez les autres promos automatiques qui ne doivent jamais se cumuler avec celle-ci. Une seule configuration sur l’une des deux promos suffit.',
                    'attr' => [
                        'class' => 'select2',
                    ],
                ]
            )
            ->add(
                'multipleByQuantity', CheckboxType::class, [
                    'required' => false,
                    'label' => 'Multiplier la remise en fonction de la quantité (Quantité total / quantité minimum )',
                ]
            )
            ->add(
                'includeShippingFees', CheckboxType::class, [
                    'required' => false,
                    'label' => 'Prendre en compte les frais de port',
                ]
            )
            ->add(
                'groups', EntityType::class,
                [
                    'class' => ProductPriceGroup::class,
                    'query_builder' => function (ProductPriceGroupRepository $er) {
                        return $er->findByNameOrderAdminQuery();
                    },
                    'choice_label' => 'name',
                    'label' => 'Groupes de prix',
                    'multiple' => true,
                    'required' => true,
                    'attr' => [
                        'class' => 'select2',
                    ],
                ]
            )
            ->add(
                'zones', EntityType::class,
                [
                    'class' => ShippingZone::class,
                    'choice_label' => 'name',
                    'label' => 'Zone(s)',
                    'multiple' => true,
                    'required' => false,
                    'help' => 'laisser vide pour prendre en compte toutes les zones',
                    'attr' => [
                        'class' => 'select2',
                    ],
                ]
            )
            ->add(
                'products', TranslatedEntityType::class, [
                    'label' => 'Produit(s) associé(s) à la remise',
                    'class' => Product::class,
                    'translation_property' => 'name',
                    'required' => false,
                    'multiple' => true,
                    'help' => 'laisser vide pour prendre en compte tous les produits',
                    'attr' => [
                        'class' => 'select2',
                    ],
                ]
            )
            ->add(
                'offeredVariant', EntityType::class, [
                    'class' => ProductVariant::class,
                    'choice_label' => 'name',
                    'label' => 'Variant offert',
                    'required' => false,
                    'help' => 'Laisser vide si la promo n’offre pas de variant.',
                    'attr' => [
                        'class' => 'select2',
                    ],
                ]
            )
            ->add(
                'assignedUser', EntityType::class, [
                    'class' => User::class,
                    'query_builder' => static fn (UserRepository $repository) => $repository->createRegisteredClientsQueryBuilder(),
                    'choice_label' => static fn (User $user): string => (string) $user->getEmail(),
                    'label' => 'Client enregistré',
                    'required' => false,
                    'placeholder' => 'Aucun client spécifique',
                    'help' => 'Si un client est sélectionné, ce code promo ne pourra être utilisé qu’une seule fois par ce client. Le mode auto est autorisé.',
                    'attr' => [
                        'class' => 'select2',
                    ],
                ]
            )
            ->add(
                'notificationEmail', EmailType::class, [
                    'required' => false,
                    'label' => 'Email de notification',
                    'help' => 'Utilisé uniquement pour prévenir cette adresse par email. Dans ce cas, la promo ne pourra être utilisée qu’une seule fois et ne peut pas être automatique.',
                ]
            );
    }

    public function configureOptions(OptionsResolver $resolver): void
    {
        $resolver->setDefaults(
            [
                'data_class' => Promo::class,
            ]
        );
    }
}
