<?php

/*
 * This file is part of the VITICORE2 package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace CpCreation\VitiCore\Cart;

final class CartPricing
{
    /**
     * @param list<CartPricingLine> $lines
     */
    public function __construct(
        public readonly array $lines,
        public readonly float $taxRate,
        public readonly int $subtotalHT,
        public readonly int $subtotalTax,
        public readonly int $subtotalTTC,
        public readonly int $discountHT,
        public readonly int $discountTax,
        public readonly int $discountTTC,
        public readonly int $degressiveHT,
        public readonly int $degressiveTax,
        public readonly int $degressiveTTC,
        public readonly int $totalHT,
        public readonly int $totalTax,
        public readonly int $totalTTC,
        public readonly bool $degressiveIsBottleOffered = false,
    ) {
    }
}
