<?php

declare(strict_types=1);

namespace CpCreation\VitiCore\Bridge\Symfony\Bundle\Event;

use CpCreation\VitiCore\User\Model\User;

final class UserAccountVerifiedEvent extends DomainEvent
{
    public function __construct(
        private readonly User $user,
        ?string $occurredOn = null,
    ) {
        parent::__construct($occurredOn);
    }

    public function user(): User
    {
        return $this->user;
    }
}
