{% extends '@CpCreationVitiCore/admin/base.html.twig' %}

{% block content %}
    <div class="panel panel-default">
        <div class="panel-heading">
            Prix frais de transport - Automatique
        </div>
        <table class="table table-striped">
            <thead>
            <tr>
                <th>#</th>
                <th>De</th>
                <th>A</th>
                <th>Departement</th>
                <th>Pays</th>
                <th>Forfait</th>
                <th>Par bouteille</th>
            </tr>
            </thead>
            <tbody>

            {% for item in items %}
                <tr>
                    <td>{{ loop.index }}</td>
                    <td>{{ item.qtyOf }}</td>
                    <td>{{ item.qtyAt }}</td>
                    <td>{{ item.county }}</td>
                    <td>{{ item.country }}</td>
                    <td>
                        {% if item.packagePrice is not null %}
                            {{ item.packagePrice / 100 }} €
                        {% endif %}
                    </td>
                    <td>
                        {% if item.bottlePrice is not null %}
                            {{ item.bottlePrice / 100 }} €
                        {% endif %}
                    </td>
                </tr>
            {% endfor %}
            </tbody>
        </table>
    </div>
{% endblock %}
