.shop-tabs-splide {
    display: block;
}

.shop-tabs-splide .splide__pagination {
    display: flex !important;
    position: static;
    margin-bottom: 0.75rem;
    justify-content: center;
    align-items: center;
    width: 100%;
    gap: 0.5rem;
}

.shop-tabs-splide .splide__pagination__page {
    margin: 0;
    height: 0.45rem;
    width: 0.45rem;
    border-radius: 9999px;
    background: rgb(56 56 56 / 0.2);
    opacity: 1;
    transform: none;
}

.shop-tabs-splide .splide__pagination__page.is-active {
    background: rgb(56 56 56 / 1);
    transform: scale(1.1);
}

@media (max-width: 767px) {
    .shop-tabs-splide:not(.is-overflow) .splide__track {
        overflow: visible;
    }

    .shop-tabs-splide:not(.is-overflow) .splide__list {
        justify-content: center;
    }
}
