<?php

/*
 * This file is part of the Serenity package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace CpCreation\VitiCore\Bridge\Symfony\Bundle\Notification\Enum;

/**
 * Enumération des différents canaux logiques utilisés pour la diffusion
 * instantanée de messages aux utilisateurs (via SSE, Mercure ou équivalent).
 *
 * Ces topics ne concernent pas les notifications persistées,
 * mais uniquement les alertes en temps réel.
 */
enum PushChannel: string
{
    case NOTIFIER = '/notifier';
}
