{% if haveGift %}
<br/>
<div class="btn-group">
    <a class="btn btn-info dropdown-toggle" href="#" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
        Cartes cadeau <span class="caret"></span>
    </a>

    <ul class="dropdown-menu">
        <li><a class="text-info" href="{{ path('admin_order_gift_download',{id: item.id}) }}"><i class="fas fa-download"></i> Télécharger</a></li>
        <li><a href="{{ path('admin_order_gift_resend',{id: item.id}) }}"><i class="fas fa-envelope"></i> Renvoyé au client</a></li>
    </ul>
</div>
<br>
{% endif %}