{% set seo_title = title_key|trans({}, 'meta') %}
{% set seo_description = description_key|trans({}, 'meta') %}
<link rel="apple-touch-icon" sizes="180x180" href="{{ asset('images/favicon/apple-touch-icon.png') }}">
<link rel="icon" type="image/png" sizes="32x32" href="{{ asset('images/favicon/favicon-32x32.png') }}">
<link rel="icon" type="image/png" sizes="16x16" href="{{ asset('images/favicon/favicon-16x16.png') }}">
<link rel="manifest" href="{{ absolute_url('site.webmanifest') }}">
<meta name="robots" content="{{ robots|default('index,follow') }}">
<meta name="description" lang="{{ app.request.locale }}" content="{{ seo_description }}">
<meta property="og:site_name" content="Champagne Saint-Réol">
<meta property="og:title" content="{{ seo_title }}">
<meta property="og:type" content="website">
<meta property="og:url" content="{{ app.request.uri }}">
<meta property="og:image" content="{{ absolute_url(asset('images/logo-meta.jpg')) }}">
<meta property="og:locale" content="{{ app.request.locale }}">
<meta property="og:image:type" content="image/jpeg">
<meta property="og:image:width" content="600">
<meta property="og:image:height" content="450">
<meta property="og:description" content="{{ seo_description }}">
