{{ 'security.mail.activation.greeting'|trans({}, null, locale|default('fr')) }}

{{ 'security.mail.activation.intro'|trans({'%company%': company }, null, locale|default('fr')) }}

{{ 'security.mail.activation.txt_instructions'|trans({}, null, locale|default('fr')) }}
{{ verification_url }}

{{ 'security.mail.activation.expiry'|trans({'%date%': expires_at|date('d/m/Y H:i') }, null, locale|default('fr')) }}

{{ 'security.mail.activation.ignore'|trans({}, null, locale|default('fr')) }}
