<!DOCTYPE html>
<html lang="{{ locale|default('fr') }}">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="x-apple-disable-message-reformatting">
    <title>Nouvelle prise de contact</title>
    <style>
        body, table, td, a {
            -webkit-text-size-adjust: 100%;
            -ms-text-size-adjust: 100%;
        }

        table {
            border-collapse: collapse !important;
        }

        img {
            border: 0;
            height: auto;
            line-height: 100%;
            outline: none;
            text-decoration: none;
            -ms-interpolation-mode: bicubic;
        }

        @media only screen and (max-width: 640px) {
            .email-shell {
                padding: 20px 12px !important;
            }

            .email-card {
                width: 100% !important;
            }

            .email-header,
            .email-body {
                padding-left: 22px !important;
                padding-right: 22px !important;
            }

            .email-header {
                padding-top: 32px !important;
                padding-bottom: 20px !important;
            }

            .email-body {
                padding-top: 26px !important;
                padding-bottom: 32px !important;
                font-size: 17px !important;
                line-height: 1.75 !important;
            }

            .email-logo {
                max-width: 150px !important;
                margin-bottom: 20px !important;
            }

            .email-eyebrow {
                font-size: 10px !important;
                letter-spacing: 0.28em !important;
            }

            .email-title {
                font-size: 28px !important;
                line-height: 1.25 !important;
            }

            .email-info-label,
            .email-info-value {
                display: block !important;
                width: 100% !important;
                padding: 0 !important;
            }

            .email-info-value {
                padding-top: 6px !important;
            }
        }
    </style>
</head>
<body style="margin:0; padding:0; background:#f7f2ea; color:#201917; font-family:Georgia, 'Times New Roman', serif;">
<table role="presentation" width="100%" cellspacing="0" cellpadding="0" style="width:100%; background:#f7f2ea; margin:0; padding:0;">
    <tr>
        <td class="email-shell" align="center" style="padding:32px 16px;">
            <table role="presentation" width="640" cellspacing="0" cellpadding="0" class="email-card" style="width:100%; max-width:640px; background:#ffffff;">
                <tr>
                    <td class="email-header" style="padding:40px 40px 24px; text-align:center; background:#fcfaf7;">
                        {% if contact and contact.image and contact.image.path %}
                            <img
                                src="{{ absolute_url(asset(contact.image.path)|imagine_filter('logo_email_filter')) }}"
                                alt="{{ contact.image.title ?: company }}"
                                width="180"
                                class="email-logo"
                                style="display:block; width:100%; max-width:180px; margin:0 auto 24px;"
                            >
                        {% endif %}
                        <div class="email-eyebrow" style="font-size:12px; letter-spacing:0.32em; text-transform:uppercase; color:#9d7c47;">Demande de contact</div>
                        <h1 class="email-title" style="margin:18px 0 0; font-size:34px; line-height:1.2; font-weight:400; color:#201917;">Nouveau message reçu</h1>
                    </td>
                </tr>
                <tr>
                    <td class="email-body" style="padding:32px 40px 40px; font-family:Arial, Helvetica, sans-serif; font-size:16px; line-height:1.75; color:#5d4b41;">
                        <p style="margin:0 0 24px;">Nouvelle prise de contact depuis le site {{ company }}.</p>

                        <table role="presentation" width="100%" cellspacing="0" cellpadding="0" style="width:100%; margin:0 0 24px; border-top:1px solid #eadfce; border-bottom:1px solid #eadfce;">
                            <tr>
                                <td class="email-info-label" style="width:150px; padding:16px 0; vertical-align:top; font-size:12px; letter-spacing:0.18em; text-transform:uppercase; color:#9d7c47;">Nom</td>
                                <td class="email-info-value" style="padding:16px 0; color:#201917;">{{ data.firstname|default('') }} {{ data.lastname|default('') }}</td>
                            </tr>
                            <tr>
                                <td class="email-info-label" style="width:150px; padding:16px 0; vertical-align:top; font-size:12px; letter-spacing:0.18em; text-transform:uppercase; color:#9d7c47;">Email</td>
                                <td class="email-info-value" style="padding:16px 0; color:#201917;">
                                    {% if data.email is defined and data.email %}
                                        <a href="mailto:{{ data.email }}" style="color:#9d7c47; text-decoration:none;">{{ data.email }}</a>
                                    {% else %}
                                        Non renseigné
                                    {% endif %}
                                </td>
                            </tr>
                            <tr>
                                <td class="email-info-label" style="width:150px; padding:16px 0; vertical-align:top; font-size:12px; letter-spacing:0.18em; text-transform:uppercase; color:#9d7c47;">Téléphone</td>
                                <td class="email-info-value" style="padding:16px 0; color:#201917;">{{ data.phone|default('Non renseigné') }}</td>
                            </tr>
                            <tr>
                                <td class="email-info-label" style="width:150px; padding:16px 0; vertical-align:top; font-size:12px; letter-spacing:0.18em; text-transform:uppercase; color:#9d7c47;">Objet</td>
                                <td class="email-info-value" style="padding:16px 0; color:#201917;">{{ data.object|default('Non renseigné') }}</td>
                            </tr>
                        </table>

                        <div style="margin:0 0 12px; font-size:12px; letter-spacing:0.18em; text-transform:uppercase; color:#9d7c47;">Message</div>
                        <div style="padding:22px; background:#fcfaf7; color:#201917;">
                            {{ data.message|default('')|nl2br }}
                        </div>
                    </td>
                </tr>
            </table>
        </td>
    </tr>
</table>
</body>
</html>
