
    {% if not form.vars.valid %}
        <div class="alert alert-danger alert-dismissible" role="alert">
            <h5>Les erreurs a corriger !</h5>
            {% if not form.vars.valid %}
                <ul class="list-error">
                    {% for error in form.vars.errors %}
                        <span class="title-error">{{ (error.origin.config.name)|trans([]) }}</span>
                        <li>{{ error.message }}</li>
                    {% endfor %}
                </ul>
            {% endif %}
            {% for children in form.children %}
                {% if not children.vars.valid %}
                    <span class="title-error"> {{ (children.vars.name)|trans([]) }}</span>
                    <ul>
                        {% for error in children.vars.errors.form.getErrors(true) %}
                            <li>{{ error.message }}</li>
                        {% endfor %}
                    </ul>
                {% endif %}
            {% endfor %}
        </div>
    {% endif %}

<div class="row">
    <div class="col-md-6">
        <div class="panel panel-info">
            <div class="panel-heading">
                Nom & Description
            </div>
            <div class="panel-body">
                <div class="a2lix_translations">
                    <ul class="a2lix_translationsLocales nav nav-tabs" role="tablist">
                        {% for translationsFields in form.translations %}
                            {% set locale = translationsFields.vars.name %}

                            <li class="nav-item {% if app.request.locale == locale %}active{% endif %}">
                                <a href="#" class="nav-link {% if app.request.locale == locale %}active{% endif %}"
                                   data-toggle="tab"
                                   data-target=".{{ translationsFields.vars.id }}_a2lix_translationsFields-{{ locale }}" role="tab"
                                   aria-expanded="true">
                                    {{ translationsFields.vars.label|default(locale|humanize)|trans }}
                                    {% if form.translations.vars.default_locale == locale %}{{ '[Default]'|trans }}{% endif %}
                                    {% if translationsFields.vars.required %}*{% endif %}
                                </a>
                            </li>
                        {% endfor %}
                    </ul>

                    <div class="a2lix_translationsFields tab-content">
                        {% for translationsFields in form.translations %}
                            {% set locale = translationsFields.vars.name %}

                            <div class="{{ translationsFields.vars.id }}_a2lix_translationsFields-{{ locale }} tab-pane {% if app.request.locale == locale %}active{% endif %} {% if not form.translations.vars.valid %}sonata-ba-field-error{% endif %}"
                                 role="tabpanel">
                                {{ form_errors(translationsFields) }}
                                {{ form_row(translationsFields.name) }}
                                {% if form.vars.data is not null and form.vars.data.slug %}
                                    <p class="help-block" style="margin-top: -10px;">
                                        <strong>Slug :</strong> {{ form.vars.data.slug }}
                                    </p>
                                {% endif %}
                                {{ form_row(translationsFields.description) }}
                                {{ form_row(translationsFields.noGroupMatchMessage) }}
                            </div>
                        {% endfor %}
                    </div>
                </div>
            </div>
        </div>
    </div>
    <div class="col-md-6">
        <div class="panel panel-info">
            <div class="panel-heading">
                Page
            </div>
            <div class="panel-body">
                {{ form_row(form.pageCuvee) }}
                {{ form_row(form.pageShop) }}
                {{ form_row(form.displayEvenWithoutGroupMatch) }}
            </div>
        </div>
    </div>
    {{ form_rest(form) }}
</div>
