<?php

/*
 * This file is part of the Serenity package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace CpCreation\VitiCore\Behavior;

use CpCreation\VitiCore\Product\Model\ProductPriceGroup;

interface HasGroupAvailable
{
    public function getGroupAvailable(): ?ProductPriceGroup;

    public function setGroupAvailable(?ProductPriceGroup $group): void;
}
