<?php

declare(strict_types=1);

namespace CpCreation\VitiCore\Bridge\Doctrine\Migrations;

use Doctrine\DBAL\Schema\Schema;
use Doctrine\Migrations\AbstractMigration;

final class Version20260327193000 extends AbstractMigration
{
    public function getDescription(): string
    {
        return 'Add translated link title to announcements';
    }

    public function up(Schema $schema): void
    {
        $this->addSql('ALTER TABLE popup_popup_translation ADD url_title TEXT DEFAULT NULL');
    }

    public function down(Schema $schema): void
    {
        $this->addSql('ALTER TABLE popup_popup_translation DROP url_title');
    }
}
