<?php

declare(strict_types=1);

namespace CpCreation\VitiCore\Bridge\Doctrine\Migrations;

use Doctrine\DBAL\Schema\Schema;
use Doctrine\Migrations\AbstractMigration;

final class Version20260427133000 extends AbstractMigration
{
    public function getDescription(): string
    {
        return 'Ajoute le template de modale sur les blocs d’information boutique';
    }

    public function up(Schema $schema): void
    {
        $this->addSql("ALTER TABLE shop_information_block ADD modal_template VARCHAR(50) DEFAULT 'none' NOT NULL");
    }

    public function down(Schema $schema): void
    {
        $this->addSql('ALTER TABLE shop_information_block DROP modal_template');
    }
}
