{% extends 'base.html.twig' %}

{% block title %}{{ 'depot.title'|trans({}, 'meta') }}{% endblock %}

{% block meta %}
    {{ include('partials/seo.html.twig', {
        title_key: 'depot.title',
        description_key: 'depot.description',
        robots: 'noindex,nofollow'
    }) }}
{% endblock meta %}

{% block stylesheets %}
    {{ parent() }}
    {{ encore_entry_link_tags('depot', null, 'front') }}
{% endblock %}

{% block javascripts %}
    {{ parent() }}
    {{ encore_entry_script_tags('depot', null, 'front') }}
{% endblock %}

{% block main %}
    <section class="pt-4 bg-light">
        <div class="mx-4 lg:mx-8 large:mx-auto max-w-large pb-20 pt-16 sm:pb-28 sm:pt-20">
            <div class="mx-auto mb-10 max-w-4xl px-6 text-center sm:px-8">
                <h1 class="flex flex-col items-center font-serif text-3xl uppercase tracking-[0.14em] text-dark sm:text-4xl lg:text-5xl after:mt-5 after:h-[2px] after:w-14 after:bg-gold">
                    {{ 'depot.title'|trans|raw }}
                </h1>
                <p class="mt-5 text-sm leading-7 text-dark/70 sm:text-base">
                    Merci de lire attentivement les presentes modalites d'utilisation du present site avant de le parcourir.
                </p>
            </div>

            <div class="mx-auto max-w-7xl">
                {{ component('depot') }}
            </div>
        </div>
    </section>
{% endblock %}
