.wizard-steps {
    list-style: none;
    display: table;
    width: 100%;
    padding: 0;
    margin: 0;
    position: relative;
}
.wizard-steps li {
    display: table-cell;
    text-align: center;
    width: 1%;
}
.wizard-steps li.active .step, .wizard-steps li.active:before, .wizard-steps li.craue_formflow_skipped_step, .wizard-steps li.complete .step, .wizard-steps li.complete:before {
    border-color: #5293c4;
}
.wizard-steps li:first-child:before {
    max-width: 51%;
    left: 50%;
}
.wizard-steps li:last-child:before {
    max-width: 50%;
    width: 50%;
}
.wizard-steps li .step {
    border: 5px solid #ced1d6;
    color: #546474;
    font-size: 15px;
    border-radius: 100%;
    background-color: #FFF;
    position: relative;
    z-index: 2;
    display: inline-block;
    width: 40px;
    height: 40px;
    line-height: 30px;
    text-align: center;
}
.wizard-steps li:before {
    display: block;
    content: "";
    width: 100%;
    height: 1px;
    font-size: 0;
    overflow: hidden;
    border-top: 4px solid #CED1D6;
    position: relative;
    top: 21px;
    z-index: 1;
}

.wizard-steps li.active .title, .wizard-steps li.complete .title,.wizard-steps li.craue_formflow_skipped_step .title {
    color: #2b3d53;
}
.wizard-steps li .title {
    display: block;
    margin-top: 4px;
    max-width: 100%;
    color: #949ea7;
    font-size: 14px;
    z-index: 104;
    text-align: center;
    table-layout: fixed;
    word-wrap: break-word;
}
.wizard-steps li.complete .step, .wizard-steps li.craue_formflow_skipped_step .step {
    cursor: default;
    color: #FFF;
    -webkit-transition: transform ease .1s;
    -o-transition: transform ease .1s;
    transition: transform ease .1s;
}
.wizard-steps li.complete .step:before,.wizard-steps li.craue_formflow_skipped_step .step:before {
    display: block;
    position: absolute;
    top: 0;
    left: 0;
    bottom: 0;
    right: 0;
    line-height: 30px;
    text-align: center;
    border-radius: 100%;
    content: "done";
    background-color: #FFF;
    z-index: 3;
    font-family: 'Material Icons';
    font-size: 17px;
    color: #87ba21;
}