import 'leaflet/dist/leaflet.css';
import 'leaflet.markercluster/dist/MarkerCluster.css';

import L from 'leaflet';
import 'leaflet.markercluster';
import stimulusManager from './js/stimulusManager';
import DepotMapController from './controllers/depot_map_controller';

window.L = L;

stimulusManager.register('depot-map', DepotMapController);
