{% extends '@CpCreationVitiCore/admin/base.html.twig' %}
{% block content %}
    <section id="login">
        {% if error %}
            <div>{{ error.messageKey|trans(error.messageData, 'security') }}</div>
        {% endif %}
        <section id="login">
            <div class="container">
                <div class="row">
                    {% if error %}
                        <div class="text-center error"><h3>{{ error.messageKey|trans(error.messageData, 'security') }}</h3></div>
                    {% endif %}
                    {% if app.request.get('back') is not null %}
                        <div class="text-center"><h3>Un nouveau mot de passe vous a été envoyé par email !</h3></div>
                    {% endif %}
                    <div class="col-md-6 col-md-offset-3">
                        <div class="panel panel-login">
                            <div class="panel-heading">
                                <div class="row">
                                    <div class="col-xs-12">
                                        <a href="#" class="active" id="login-form-link">Identification</a>
                                    </div>
                                </div>
                                <hr>
                            </div>
                            <div class="panel-body">
                                <div class="row">
                                    <div class="col-lg-12">
                                        <form action="{{ path('login') }}" method="post" style="display: block;">
                                            <div class="form-group">
                                                <input type="text" id="username" name="_username" class="form-control" placeholder="Identifiant" value="{{ last_username }}"/>
                                            </div>
                                            <div class="form-group">
                                                <input type="password" id="password" name="_password" class="form-control" placeholder="Mot de passe"/>
                                            </div>
                                            <div class="form-group">
                                                <div class="row">
                                                    <div class="col-sm-6 col-sm-offset-3">
                                                        <input type="submit" name="login-submit" id="login-submit" tabindex="4" class="form-control btn btn-login" value="Connexion">
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="form-group">
                                                <div class="row">
                                                    <div class="col-lg-12">
                                                        <div class="text-center">
                                                            <a href="#" tabindex="5" class="forgot-password">Mot de passe oublié ?</a>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </form>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    </section>
{% endblock content %}